@@ -25,13 +25,18 @@ AutoCorrectionLanguage::AutoCorrectionLanguage(QWidget *parent)
     for (int i = QLocale::Abkhazian; i <= QLocale::LastLanguage; ++i) {
         const auto lang = static_cast<QLocale::Language>(i);
         QLocale locale(lang);
-        if (locale.name() == QLatin1String("C"))
+        if (locale.name() == QLatin1String("C")) {
             continue;
+        }
         addItem(QLocale::system().languageToString(lang), locale.name());
     }
-    auto defaultLang = QLocale::system().uiLanguages().at(0);
-    if (defaultLang == QLatin1String("C"))
-        defaultLang = QStringLiteral("en_US");
+    QString defaultLang;
+    if (!QLocale::system().uiLanguages().isEmpty()) {
+        defaultLang = QLocale::system().uiLanguages().at(0);
+        if (defaultLang == QLatin1String("C")) {
+            defaultLang = QStringLiteral("en_US");
+        }
+    }
     const int index = findData(defaultLang);
     setCurrentIndex(index);
     model()->sort(0);
