@@ -17,10 +17,14 @@
 
 #include "genericplugin.h"
 #include "genericpluginmanager.h"
+#include "pimcommon_debug.h"
+#include "pluginutil.h"
 
 #include <kpluginmetadata.h>
 #include <KPluginLoader>
 #include <KPluginFactory>
+#include <KSharedConfig>
+#include <KConfigGroup>
 #include <qfileinfo.h>
 #include <QVariant>
 #include <QSet>
@@ -51,21 +55,18 @@ class GenericPluginInfo
 {
 public:
     GenericPluginInfo()
-        : plugin(Q_NULLPTR)
+        : plugin(Q_NULLPTR),
+          isEnabled(true)
     {
 
     }
-    QString saveName() const;
-
-    KPluginMetaData metaData;
+    QString metaDataFileNameBaseName;
+    QString metaDataFileName;
+    PimCommon::PluginUtilData pluginData;
     PimCommon::GenericPlugin *plugin;
+    bool isEnabled;
 };
 
-QString GenericPluginInfo::saveName() const
-{
-    return QFileInfo(metaData.fileName()).baseName();
-}
-
 namespace
 {
 QString pluginVersion()
@@ -88,38 +89,66 @@ public:
     QString serviceTypeName;
     QString pluginName;
     QVector<GenericPluginInfo> mPluginList;
+
+    QVector<PluginUtilData> pluginsDataList() const;
+    QString configGroupName() const;
+    QString configPrefixSettingKey() const;
+    GenericPlugin *pluginFromIdentifier(const QString &id);
+private:
+    QVector<PluginUtilData> mPluginDataList;
     GenericPluginManager *q;
 };
 
+QString GenericPluginManagerPrivate::configGroupName() const
+{
+    return QStringLiteral("GenericPlugin-%1").arg(pluginName);
+}
+
+QString GenericPluginManagerPrivate::configPrefixSettingKey() const
+{
+    return QStringLiteral("%1Plugin").arg(pluginName);
+}
+
 bool GenericPluginManagerPrivate::initializePlugins()
 {
-    if (serviceTypeName.isEmpty() || pluginName.isEmpty()) {
-        return false;
-    }
     if (!mPluginList.isEmpty()) {
         return true;
     }
+
+    if (serviceTypeName.isEmpty() || pluginName.isEmpty()) {
+        return false;
+    }
     static const QString s_serviceTypeName = serviceTypeName;
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(pluginName, [](const KPluginMetaData & md) {
         return md.serviceTypes().contains(s_serviceTypeName);
     });
 
+    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
     QSet<QString> unique;
     while (i.hasPrevious()) {
         GenericPluginInfo info;
-        info.metaData = i.previous();
-        if (pluginVersion() == info.metaData.version()) {
+        const KPluginMetaData data = i.previous();
+
+        //1) get plugin data => name/description etc.
+        info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
+        //2) look at if plugin is activated
+        const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
+        info.isEnabled = isPluginActivated;
+        info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
+        info.metaDataFileName = data.fileName();
+
+        if (pluginVersion() == data.version()) {
             // only load plugins once, even if found multiple times!
-            if (unique.contains(info.saveName())) {
+            if (unique.contains(info.metaDataFileNameBaseName)) {
                 continue;
             }
             info.plugin = Q_NULLPTR;
             mPluginList.push_back(info);
-            unique.insert(info.saveName());
+            unique.insert(info.metaDataFileNameBaseName);
         } else {
-            qWarning() << "Plugin " << info.metaData.name() << " doesn't have correction plugin version. It will not be loaded.";
+            qCWarning(PIMCOMMON_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
     }
     QVector<GenericPluginInfo>::iterator end(mPluginList.end());
@@ -129,6 +158,11 @@ bool GenericPluginManagerPrivate::initializePlugins()
     return true;
 }
 
+QVector<PluginUtilData> GenericPluginManagerPrivate::pluginsDataList() const
+{
+    return mPluginDataList;
+}
+
 QVector<GenericPlugin *> GenericPluginManagerPrivate::pluginsList() const
 {
     QVector<PimCommon::GenericPlugin *> lst;
@@ -143,12 +177,26 @@ QVector<GenericPlugin *> GenericPluginManagerPrivate::pluginsList() const
 
 void GenericPluginManagerPrivate::loadPlugin(GenericPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaData.fileName());
+    KPluginLoader pluginLoader(item->metaDataFileName);
     if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<PimCommon::GenericPlugin>(q, QVariantList() << item->saveName());
+        item->plugin = pluginLoader.factory()->create<PimCommon::GenericPlugin>(q, QVariantList() << item->metaDataFileNameBaseName);
+        item->plugin->setIsEnabled(item->isEnabled);
+        item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
+        mPluginDataList.append(item->pluginData);
     }
 }
 
+GenericPlugin *GenericPluginManagerPrivate::pluginFromIdentifier(const QString &id)
+{
+    QVector<GenericPluginInfo>::ConstIterator end(mPluginList.constEnd());
+    for (QVector<GenericPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
+        if ((*it).pluginData.mIdentifier == id) {
+            return (*it).plugin;
+        }
+    }
+    return {};
+}
+
 GenericPluginManager::GenericPluginManager(QObject *parent)
     : QObject(parent),
       d(new GenericPluginManagerPrivate(this))
@@ -196,3 +244,22 @@ QVector<GenericPlugin *> GenericPluginManager::pluginsList() const
     return d->pluginsList();
 }
 
+QVector<PluginUtilData> GenericPluginManager::pluginsDataList() const
+{
+    return d->pluginsDataList();
+}
+
+QString GenericPluginManager::configGroupName() const
+{
+    return d->configGroupName();
+}
+
+QString GenericPluginManager::configPrefixSettingKey() const
+{
+    return d->configPrefixSettingKey();
+}
+
+GenericPlugin *GenericPluginManager::pluginFromIdentifier(const QString &id)
+{
+    return d->pluginFromIdentifier(id);
+}
